@@ -1400,9 +1400,7 @@ class _EVMMixin:
       
       # Estimate gas fees for the token transfer.
       gas_price = w3vars.w3.eth.gas_price  # This fetches the current suggested gas price from the network.
-      estimated_gas = poai_manager_contract.functions.submitNodeUpdate(job_id, nodes).estimate_gas(
-        {'from': self.eth_address}
-      )
+      estimated_gas = 750_000 # Have enough gas to cover all the actions if consensus is reached
       gas_cost = estimated_gas * gas_price
       
       # Check that the sender's ETH balance can cover gas costs plus an extra buffer.
